@@ -2,10 +2,8 @@ package version::regex;
 
 use strict;
 
-use vars qw($VERSION $CLASS $STRICT $LAX);
-
-$VERSION = '0.9913_01';
-$VERSION = eval $VERSION;
+our $VERSION = '0.9923_02';
+#$VERSION =~ s/c$//;
 
 #--------------------------------------------------------------------------#
 # Version regexp components
@@ -50,7 +48,8 @@ my $LAX_DOTTED_DECIMAL_PART = qr/\.[0-9]+/;
 # Alpha suffix part of lax version number syntax.  Acts like a
 # dotted-decimal part.
 
-my $LAX_ALPHA_PART = qr/_[0-9]+/;
+#my $LAX_ALPHA_PART = qr/_[0-9]+/;
+my $LAX_ALPHA_PART = qr/(?:_[0-9]+c?|c?)/;
 
 #--------------------------------------------------------------------------#
 # Strict version regexp definitions
@@ -58,19 +57,19 @@ my $LAX_ALPHA_PART = qr/_[0-9]+/;
 
 # Strict decimal version number.
 
-my $STRICT_DECIMAL_VERSION =
-    qr/ $STRICT_INTEGER_PART $FRACTION_PART? /x;
+our $STRICT_DECIMAL_VERSION =
+    qr/ $STRICT_INTEGER_PART $FRACTION_PART? c? /x;
 
 # Strict dotted-decimal version number.  Must have both leading "v" and
 # at least three parts, to avoid confusion with decimal syntax.
 
-my $STRICT_DOTTED_DECIMAL_VERSION =
-    qr/ v $STRICT_INTEGER_PART $STRICT_DOTTED_DECIMAL_PART{2,} /x;
+our $STRICT_DOTTED_DECIMAL_VERSION =
+    qr/ v $STRICT_INTEGER_PART $STRICT_DOTTED_DECIMAL_PART{2,} c? /x;
 
 # Complete strict version number syntax -- should generally be used
 # anchored: qr/ \A $STRICT \z /x
 
-$STRICT =
+our $STRICT =
     qr/ $STRICT_DECIMAL_VERSION | $STRICT_DOTTED_DECIMAL_VERSION /x;
 
 #--------------------------------------------------------------------------#
@@ -81,8 +80,8 @@ $STRICT =
 # allowing an alpha suffix or allowing a leading or trailing
 # decimal-point
 
-my $LAX_DECIMAL_VERSION =
-    qr/ $LAX_INTEGER_PART (?: \. | $FRACTION_PART $LAX_ALPHA_PART? )?
+our $LAX_DECIMAL_VERSION =
+    qr/ $LAX_INTEGER_PART (?: $FRACTION_PART | \. )? $LAX_ALPHA_PART?
 	|
 	$FRACTION_PART $LAX_ALPHA_PART?
     /x;
@@ -93,7 +92,7 @@ my $LAX_DECIMAL_VERSION =
 # enough, without the leading "v", Perl takes .1.2 to mean v0.1.2,
 # so when there is no "v", the leading part is optional
 
-my $LAX_DOTTED_DECIMAL_VERSION =
+our $LAX_DOTTED_DECIMAL_VERSION =
     qr/
 	v $LAX_INTEGER_PART (?: $LAX_DOTTED_DECIMAL_PART+ $LAX_ALPHA_PART? )?
 	|
@@ -106,8 +105,8 @@ my $LAX_DOTTED_DECIMAL_VERSION =
 # The string 'undef' is a special case to make for easier handling
 # of return values from ExtUtils::MM->parse_version
 
-$LAX =
-    qr/ undef | $LAX_DECIMAL_VERSION | $LAX_DOTTED_DECIMAL_VERSION /x;
+our $LAX =
+    qr/ undef | $LAX_DOTTED_DECIMAL_VERSION | $LAX_DECIMAL_VERSION /x;
 
 #--------------------------------------------------------------------------#
 
