@@ -115,7 +115,7 @@ S_croak_xs_usage(pTHX_ const CV *const cv, const char *const params)
             Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
     } else {
         /* Pants. I don't think that it should be possible to get here. */
-        Perl_croak_nocontext("Usage: CODE(0x%"UVxf")(%s)", PTR2UV(cv), params);
+        Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
     }
 }
 
@@ -131,16 +131,16 @@ S_croak_xs_usage(pTHX_ const CV *const cv, const char *const params)
 
 #  define VUTIL_REPLACE_CORE 1
 
-static const char * Perl_scan_version2(pTHX_ const char *s, SV *rv, bool qv);
-static SV * Perl_new_version2(pTHX_ SV *ver);
-static SV * Perl_upg_version2(pTHX_ SV *sv, bool qv);
-static SV * Perl_vstringify2(pTHX_ SV *vs);
-static SV * Perl_vverify2(pTHX_ SV *vs);
-static SV * Perl_vnumify2(pTHX_ SV *vs);
-static SV * Perl_vnormal2(pTHX_ SV *vs);
-static SV * Perl_vstringify2(pTHX_ SV *vs);
-static int Perl_vcmp2(pTHX_ SV *lsv, SV *rsv);
-static const char * Perl_prescan_version2(pTHX_ const char *s, bool strict, const char** errstr, bool *sqv, int *ssaw_decimal, int *swidth, bool *salpha);
+const char * Perl_scan_version2(pTHX_ const char *s, SV *rv, bool qv);
+SV * Perl_new_version2(pTHX_ SV *ver);
+SV * Perl_upg_version2(pTHX_ SV *sv, bool qv);
+SV * Perl_vstringify2(pTHX_ SV *vs);
+SV * Perl_vverify2(pTHX_ SV *vs);
+SV * Perl_vnumify2(pTHX_ SV *vs);
+SV * Perl_vnormal2(pTHX_ SV *vs);
+SV * Perl_vstringify2(pTHX_ SV *vs);
+int Perl_vcmp2(pTHX_ SV *lsv, SV *rsv);
+const char * Perl_prescan_version2(pTHX_ const char *s, bool strict, const char** errstr, bool *sqv, int *ssaw_decimal, int *swidth, bool *salpha);
 
 #  define SCAN_VERSION(a,b,c)	Perl_scan_version2(aTHX_ a,b,c)
 #  define NEW_VERSION(a)	Perl_new_version2(aTHX_ a)
@@ -223,36 +223,56 @@ const char * Perl_prescan_version(pTHX_ const char *s, bool strict, const char**
 #endif
 
 
-#if PERL_VERSION_LT(5,27,9)
+#if !defined(LC_NUMERIC_LOCK) /* PERL_VERSION_LT(5,27,9) */
 #  define LC_NUMERIC_LOCK
 #  define LC_NUMERIC_UNLOCK
-#if PERL_VERSION_LT(5,19,0)
-#   undef STORE_LC_NUMERIC_SET_STANDARD
-#   undef RESTORE_LC_NUMERIC
-#   undef DECLARATION_FOR_LC_NUMERIC_MANIPULATION
-# ifdef USE_LOCALE
-#    define DECLARATION_FOR_LC_NUMERIC_MANIPULATION char *loc
-#    define STORE_NUMERIC_SET_STANDARD()\
-	loc = savepv(setlocale(LC_NUMERIC, NULL));  \
-	SAVEFREEPV(loc); \
-	setlocale(LC_NUMERIC, "C");
-
-#    define RESTORE_LC_NUMERIC()\
-	setlocale(LC_NUMERIC, loc);
-# else
-#    define DECLARATION_FOR_LC_NUMERIC_MANIPULATION
-#    define STORE_LC_NUMERIC_SET_STANDARD()
-#    define RESTORE_LC_NUMERIC()
-#   endif
-# endif
+#  if PERL_VERSION_LT(5,19,0)
+#    undef STORE_LC_NUMERIC_SET_STANDARD
+#    undef RESTORE_LC_NUMERIC
+#    undef DECLARATION_FOR_LC_NUMERIC_MANIPULATION
+#    ifdef USE_LOCALE
+#      define DECLARATION_FOR_LC_NUMERIC_MANIPULATION char *loc
+#      define STORE_NUMERIC_SET_STANDARD()\
+	 loc = savepv(setlocale(LC_NUMERIC, NULL));  \
+	 SAVEFREEPV(loc); \
+	 setlocale(LC_NUMERIC, "C");
+#      define RESTORE_LC_NUMERIC()\
+	 setlocale(LC_NUMERIC, loc);
+#    else
+#      define DECLARATION_FOR_LC_NUMERIC_MANIPULATION
+#      define STORE_LC_NUMERIC_SET_STANDARD()
+#      define RESTORE_LC_NUMERIC()
+#    endif
+#  endif
 #endif
 
 #ifndef LOCK_NUMERIC_STANDARD
-#define LOCK_NUMERIC_STANDARD()
+#  define LOCK_NUMERIC_STANDARD()
 #endif
 
 #ifndef UNLOCK_NUMERIC_STANDARD
-#define UNLOCK_NUMERIC_STANDARD()
+#  define UNLOCK_NUMERIC_STANDARD()
+#endif
+
+/* The names of these changed in 5.28 */
+#ifndef LOCK_LC_NUMERIC_STANDARD
+#  define LOCK_LC_NUMERIC_STANDARD() LOCK_NUMERIC_STANDARD()
+#endif
+#ifndef UNLOCK_LC_NUMERIC_STANDARD
+#  define UNLOCK_LC_NUMERIC_STANDARD() UNLOCK_NUMERIC_STANDARD()
+#endif
+
+/* from cperl */
+#ifndef strNEs
+#  define strNEs(s1,s2) (strncmp(s1,"" s2 "", sizeof(s2)-1))
+#endif
+#ifndef strEQc
+#  define strEQc(s, c) memEQ(s, ("" c ""), sizeof(c))
+#  define strNEc(s, c) memNE(s, ("" c ""), sizeof(c))
+#endif
+#ifndef hv_existss
+#  define hv_existss(hv, key) \
+          hv_exists((hv), ("" key ""), (sizeof(key)-1))
 #endif
 
 /* ex: set ro: */
